==> qore-0.9.14.tar.bz2: qore-0.9.14/docs/modules/DbDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "DbDataProvider", "namespace_db_data_provider.html", [
      [ "AbstractDbRecordIterator", "class_db_data_provider_1_1_abstract_db_record_iterator.html", "class_db_data_provider_1_1_abstract_db_record_iterator" ],
      [ "AbstractDbTableBulkOperation", "class_db_data_provider_1_1_abstract_db_table_bulk_operation.html", "class_db_data_provider_1_1_abstract_db_table_bulk_operation" ],
      [ "DbDataProvider", "class_db_data_provider_1_1_db_data_provider.html", "class_db_data_provider_1_1_db_data_provider" ],
      [ "DbDataProviderFactory", "class_db_data_provider_1_1_db_data_provider_factory.html", "class_db_data_provider_1_1_db_data_provider_factory" ],
      [ "DbSelectBulkRecordInterface", "class_db_data_provider_1_1_db_select_bulk_record_interface.html", "class_db_data_provider_1_1_db_select_bulk_record_interface" ],
      [ "DbSelectRecordIterator", "class_db_data_provider_1_1_db_select_record_iterator.html", "class_db_data_provider_1_1_db_select_record_iterator" ],
      [ "DbTableBulkInserter", "class_db_data_provider_1_1_db_table_bulk_inserter.html", "class_db_data_provider_1_1_db_table_bulk_inserter" ],
      [ "DbTableBulkRecordInterface", "class_db_data_provider_1_1_db_table_bulk_record_interface.html", "class_db_data_provider_1_1_db_table_bulk_record_interface" ],
      [ "DbTableBulkUpserter", "class_db_data_provider_1_1_db_table_bulk_upserter.html", "class_db_data_provider_1_1_db_table_bulk_upserter" ],
      [ "DbTableDataProvider", "class_db_data_provider_1_1_db_table_data_provider.html", "class_db_data_provider_1_1_db_table_data_provider" ],
      [ "DbTableRecordIterator", "class_db_data_provider_1_1_db_table_record_iterator.html", "class_db_data_provider_1_1_db_table_record_iterator" ]
    ] ]
];

==> qore-1.12.0.tar.bz2: qore-1.12.0/docs/modules/DbDataProvider/html/annotated_dup.js <==
var annotated_dup =
[
    [ "DbDataProvider", "namespace_db_data_provider.html", [
      [ "AbstractDbRecordIterator", "class_db_data_provider_1_1_abstract_db_record_iterator.html", "class_db_data_provider_1_1_abstract_db_record_iterator" ],
      [ "AbstractDbTableBulkOperation", "class_db_data_provider_1_1_abstract_db_table_bulk_operation.html", "class_db_data_provider_1_1_abstract_db_table_bulk_operation" ],
      [ "DbDataProvider", "class_db_data_provider_1_1_db_data_provider.html", "class_db_data_provider_1_1_db_data_provider" ],
      [ "DbDataProviderFactory", "class_db_data_provider_1_1_db_data_provider_factory.html", "class_db_data_provider_1_1_db_data_provider_factory" ],
      [ "DbForeignConstraintDataType", "class_db_data_provider_1_1_db_foreign_constraint_data_type.html", "class_db_data_provider_1_1_db_foreign_constraint_data_type" ],
      [ "DbForeignConstraintsDataType", "class_db_data_provider_1_1_db_foreign_constraints_data_type.html", "class_db_data_provider_1_1_db_foreign_constraints_data_type" ],
      [ "DbIndexDataType", "class_db_data_provider_1_1_db_index_data_type.html", "class_db_data_provider_1_1_db_index_data_type" ],
      [ "DbIndexesDataType", "class_db_data_provider_1_1_db_indexes_data_type.html", "class_db_data_provider_1_1_db_indexes_data_type" ],
      [ "DbSelectBulkRecordInterface", "class_db_data_provider_1_1_db_select_bulk_record_interface.html", "class_db_data_provider_1_1_db_select_bulk_record_interface" ],
      [ "DbSelectRecordIterator", "class_db_data_provider_1_1_db_select_record_iterator.html", "class_db_data_provider_1_1_db_select_record_iterator" ],
      [ "DbTableBulkInserter", "class_db_data_provider_1_1_db_table_bulk_inserter.html", "class_db_data_provider_1_1_db_table_bulk_inserter" ],
      [ "DbTableBulkRecordInterface", "class_db_data_provider_1_1_db_table_bulk_record_interface.html", "class_db_data_provider_1_1_db_table_bulk_record_interface" ],
      [ "DbTableBulkUpserter", "class_db_data_provider_1_1_db_table_bulk_upserter.html", "class_db_data_provider_1_1_db_table_bulk_upserter" ],
      [ "DbTableDataProvider", "class_db_data_provider_1_1_db_table_data_provider.html", "class_db_data_provider_1_1_db_table_data_provider" ],
      [ "DbTableRecordIterator", "class_db_data_provider_1_1_db_table_record_iterator.html", "class_db_data_provider_1_1_db_table_record_iterator" ]
    ] ]
];
